@@ -4,6 +4,9 @@ Capture API using the libpcap.
 """
 import logging
 
+from collections import namedtuple
+
+PCAPHeader = namedtuple('PCAPHeader', ['ts_sec', 'ts_usec', 'len', 'caplen'])
 
 from .libpcap_ext import lib as pcap_lib
 from .libpcap_ext import ffi as pcap_ffi
@@ -53,7 +56,7 @@ class WishpyCapturer:
         """
         pass
 
-class LibpcapCapturer(WishpyCapturer):
+class LibpcapCapturerIface(WishpyCapturer):
     """'libpcap' based packet capturer for an interface on the system.
 
         This capturer captures packet from the OS interface and posts them,
@@ -116,7 +119,7 @@ class LibpcapCapturer(WishpyCapturer):
     def timeout(self):
         return self.__timeout
 
-    def start(self, count=-1):
+    def start(self, count=-1, serialize=False):
         """ Starts capturing of the packets on our Interface.
 
             Note: This is a blocking function and an application should
@@ -125,7 +128,9 @@ class LibpcapCapturer(WishpyCapturer):
 
             Args:
                 count: (optional) if specified should be a positive integer
-                specifying maximum number of packets to be captured.
+                    specifying maximum number of packets to be captured.
+                serialize: bool, optional - if specified serializes the header
+                    and data to `PCAPHeader` and `bytes` objects
 
             Returns:
                 On Success Nothing
@@ -134,10 +139,21 @@ class LibpcapCapturer(WishpyCapturer):
                 On Error Condition, `WishpyCapturerCaptureError`.
         """
 
-        _logger.debug("LibpcapCapturer.start")
+        _logger.debug("LibpcapCapturerIface.start")
 
         def capture_callback(user, hdr, data):
-            self.__queue.put((hdr, data,))
+
+            if serialize:
+                ## Convert this into - sensible Header, Data 'pickle'able
+                hdr = hdr[0]
+                caplen = hdr.caplen
+                ser_header = PCAPHeader(
+                        *(hdr.ts.tv_sec, hdr.ts.tv_usec,
+                            caplen, hdr.len))
+                ser_data = bytes(pcap_ffi.unpack(data, caplen))
+                self.__queue.put((ser_header, ser_data))
+            else:
+                self.__queue.put((hdr, data,))
 
         _cb = pcap_ffi.callback(
                 'void (*)(u_char *, const struct pcap_pkthdr *, const u_char *)',
@@ -152,7 +168,7 @@ class LibpcapCapturer(WishpyCapturer):
         Simply calls internal libpcap's `pcap_breakloop`
         """
 
-        _logger.debug("LibpcapCapturer.stop")
+        _logger.debug("LibpcapCapturerIface.stop")
         pcap_lib.pcap_breakloop(self.__pcap_handle)
 
     def open(self):
@@ -163,11 +179,11 @@ class LibpcapCapturer(WishpyCapturer):
             finally activates the handle.
         """
 
-        _logger.debug("LibpcapCapturer.open")
+        _logger.debug("LibpcapCapturerIface.open")
 
         err_buff = pcap_ffi.new('char [256]')
         handle = pcap_lib.pcap_create(self.__iface.encode(), err_buff)
-        if handle is None:
+        if handle == pcap_ffi.NULL:
             err_str = pcap_ffi.string(err_buff)
             raise WishpyCapturerOpenError(err_str)
 
@@ -210,16 +226,16 @@ class LibpcapCapturer(WishpyCapturer):
         self.__pcap_activated = False
         self.__pcap_handle = None
 
-        _logger.debug("LibpcapCapturer.close")
+        _logger.debug("LibpcapCapturerIface.close")
 
     def __repr__(self):
-        return "LibpcapCapturer iface:{}, snaplen:{}, promisc:{}, timeout:{}".\
+        return "LibpcapCapturerIface iface:{}, snaplen:{}, promisc:{}, timeout:{}".\
                 format(self.__iface, self.__snaplen,
                         self.__promisc, self.__timeout)
 
 if __name__ == '__main__':
     from queue import Queue
-    c = LibpcapCapturer('wlp2s0', Queue())
+    c = LibpcapCapturerIface('wlp2s0', Queue())
     print(c)
     c.open()
     c.start(count=1)
