@@ -1,5 +1,18 @@
-"""
-Our Dissector API.
+"""APIs for wireshark's dissectors.
+
+This module provides consistent APIs for using wireshark's dissector in
+different scenarios. viz. using with live packet capture and using with
+a PCAP file. A couple of dissector classes are provided that can be directly used.
+
+WishpyDissectorQueuePython : Can be used with `wishpy.libpcap.lib.capturer.Capturer`
+WishpyDissectorFile: Can be used for printing json data from a pcap(ish) file.
+
+Example:
+
+>>> d = WishpyDissectorFile('file.pcap')
+>>> for packet in d.run():
+    print(packet)
+
 """
 import socket
 import struct
@@ -10,24 +23,33 @@ import unicodedata
 import logging
 
 from ._wrapper import *
-
+from ...libpcap.lib.capturer import PCAPHeader, pcap_ffi
 
 class WishpyErrorInitDissector(Exception):
+    """Error raised during initialization of dissector and or dissector session.
+    """
     pass
 
 class WishpyEpanLibUninitializedError(Exception):
+    """Error raised during initialization of EPAN library.
+    """
     pass
 
 class WishpyEpanLibAlreadyInitialized(Exception):
+    """Error raised trying to initialize already initialized EPAN Library.
+    """
     pass
 
 class WishpyErrorWthOpen(Exception):
+    """Error raised during opening a Pcap file.
+    """
     pass
 
 _logger = logging.getLogger(__name__)
 
 _EPAN_LIB_INITIALIZED = False
 
+
 class WishpyDissectorBase:
     """ A Class that wraps the underlying dissector from epan module of
     `libwireshark`. Right now this simply prints the dissector tree.
@@ -35,11 +57,14 @@ class WishpyDissectorBase:
 
     _pretty = False
 
+    _test_json = False
+
     # We are having these definitions in the class because a lot many of them
     # are used in fast path and having them dereferenced here gives us some
     # performance, so why not?
     NULL = epan_ffi.NULL
     epan_string = epan_ffi.string
+    addressof = epan_ffi.addressof
 
     BASE_NONE = epan_lib.BASE_NONE
     BASE_DEC = epan_lib.BASE_DEC
@@ -91,6 +116,9 @@ class WishpyDissectorBase:
     FT_UINT64 = epan_lib.FT_UINT64
     FT_FRAMENUM = epan_lib.FT_FRAMENUM
 
+    FT_FLOAT = epan_lib.FT_FLOAT
+    FT_DOUBLE = epan_lib.FT_DOUBLE
+
 
 
     epan_int_types = [
@@ -115,6 +143,9 @@ class WishpyDissectorBase:
 
     epan_all_int_types = epan_int_types + epan_uint_types
 
+    unquoted_types = epan_all_int_types + \
+            [FT_BOOLEAN, FT_RELATIVE_TIME, FT_FLOAT, FT_DOUBLE]
+
     # Below are some dict's required for printing few packet types
     hfbases = {
             BASE_NONE : ('{:d}', False), # Not sure how this is to be treated
@@ -129,6 +160,18 @@ class WishpyDissectorBase:
 
      }
 
+    FTREPR_DISPLAY = epan_lib.FTREPR_DISPLAY
+    fvalue_to_string_repr = epan_lib.fvalue_to_string_repr
+    wmem_free = epan_lib.wmem_free
+
+    @classmethod
+    def enable_json_test(cls):
+        cls._test_json = True
+
+    @classmethod
+    def enable_pretty_print(cls):
+        self._pretty = True
+
     @classmethod
     def remove_ctrl_chars(cls, s):
         """Removes the Ctrl Characters from the string.
@@ -313,32 +356,53 @@ class WishpyDissectorBase:
             return "{} {}".format(ftype, display), True
 
     @classmethod
-    def print_dissected_tree_pretty(cls, node_ptr, level=1):
+    def print_dissected_tree_pretty_ftype_api(cls, node_ptr, level=1):
         """Returns a string that represents a dissected tree.
         """
         return_str = ""
 
         node = node_ptr[0]
         finfo = node.finfo
+
+        finfo_display_str = None
         if finfo != cls.NULL:
 
             hfinfo = finfo.hfinfo[0]
+            display = hfinfo.display
             abbrev = cls.epan_string(hfinfo.abbrev).decode()
             abbrev_str = '"' + abbrev + '"'
             return_str += abbrev_str + " : "
-            finfo_display_str, quote = cls.value_to_str(finfo)
-            if finfo_display_str:
-                if quote:
-                    finfo_display_str = '"' + finfo_display_str + '"'
-        else:
-            finfo_display_str = ""
+            finfo_str = cls.fvalue_to_string_repr(
+                    cls.NULL,
+                    cls.addressof(finfo[0].value),
+                    cls.FTREPR_DISPLAY,
+                    display)
 
-        if finfo_display_str is not None:
-            return_str += finfo_display_str
+            if finfo_str != cls.NULL:
+                finfo_display_str = cls.epan_string(finfo_str).decode()
+                if hfinfo.type not in cls.unquoted_types:
+                    if hfinfo.type == cls.FT_STRING:
+                        finfo_display_str = finfo_display_str.\
+                                replace('\\', '\\\\').replace('"', '\\"')
+                        finfo_display_str = cls.remove_ctrl_chars(finfo_display_str)
+                    finfo_display_str = '"' + finfo_display_str + '"'
+                else:
+                    try:
+                        _, quote = cls.hfbases[display]
+                    except KeyError as e:
+                        quote = True
+
+                    if quote:
+                        finfo_display_str = '"' + finfo_display_str + '"'
+
+                cls.wmem_free(cls.NULL, finfo_str)
+
+                return_str += finfo_display_str
 
         lspaces = " " * level
         lspaces_1 = " " * (level - 1)
         newlevel = level + 1
+
         child = node.first_child
         if child != cls.NULL:
 
@@ -355,7 +419,7 @@ class WishpyDissectorBase:
             return_str += "\n"
             while child != cls.NULL:
                 return_str += lspaces
-                return_str += cls.print_dissected_tree_pretty(child, newlevel)
+                return_str += cls.print_dissected_tree_pretty_ftype_api(child, newlevel)
                 child = child.next
             return_str += lspaces
 
@@ -417,6 +481,74 @@ class WishpyDissectorBase:
 
         return return_str
 
+    @classmethod
+    def print_dissected_tree_ftype_api(cls, node_ptr):
+        """Returns a string representing dissected tree using the `ftypes` API.
+        """
+        return_str = ""
+
+        node = node_ptr[0]
+        finfo = node.finfo
+
+        finfo_display_str = None
+        if finfo != cls.NULL:
+
+            hfinfo = finfo.hfinfo[0]
+            display = hfinfo.display
+            abbrev = cls.epan_string(hfinfo.abbrev).decode()
+            abbrev_str = '"' + abbrev + '"'
+            return_str += abbrev_str + ":"
+            finfo_str = cls.fvalue_to_string_repr(
+                    cls.NULL,
+                    cls.addressof(finfo[0].value),
+                    cls.FTREPR_DISPLAY,
+                    display)
+
+            if finfo_str != cls.NULL:
+                finfo_display_str = cls.epan_string(finfo_str).decode()
+                if hfinfo.type not in cls.unquoted_types:
+                    if hfinfo.type == cls.FT_STRING:
+                        finfo_display_str = finfo_display_str.\
+                                replace('\\', '\\\\').replace('"', '\\"')
+                        finfo_display_str = cls.remove_ctrl_chars(finfo_display_str)
+                    finfo_display_str = '"' + finfo_display_str + '"'
+                else:
+                    try:
+                        _, quote = cls.hfbases[display]
+                    except KeyError as e:
+                        quote = True
+
+                    if quote:
+                        finfo_display_str = '"' + finfo_display_str + '"'
+
+                cls.wmem_free(cls.NULL, finfo_str)
+
+                return_str += finfo_display_str
+
+        child = node.first_child
+        if child != cls.NULL:
+
+            if finfo_display_str:
+                return_str += ","
+
+                abbrev_tree = abbrev + "_tree"
+                abbrev_tree_str = '"' + abbrev_tree + '"'
+                return_str += abbrev_tree_str + ":"
+
+            return_str += "{"
+            while child != cls.NULL:
+                return_str += cls.print_dissected_tree_ftype_api(child)
+                child = child.next
+
+            return_str += "}"
+        else: # child is not None So we have someone who's FT_NONE, FT_PROTOCOL and no tree?
+            if not finfo_display_str:
+                return_str += "\"\""
+        if node.next != cls.NULL:
+            return_str += ","
+
+        return return_str
+
     @classmethod
     def packet_to_json(cls, handle_ptr):
         """ An example method that depicts how to use internal dissector API."""
@@ -425,11 +557,15 @@ class WishpyDissectorBase:
 
         # FIXME: following should be like json dumps
         if cls._pretty:
-            s = cls.print_dissected_tree_pretty(dissector.tree)
+            s = cls.print_dissected_tree_pretty_ftype_api(dissector.tree)
         else:
-            s = cls.print_dissected_tree(dissector.tree)
+            s = cls.print_dissected_tree_ftype_api(dissector.tree)
         try:
-            x = json.loads(s, strict=False)
+            if cls._test_json:
+                _ = json.loads(s, strict=False)
+        except json.decoder.JSONDecodeError as e:
+            _logger.exception("packet_to_json", e.doc)
+            return {}
         except Exception as e:
             _logger.exception("packet_to_json")
             # FIXME: May be we should raise, let caller take care.
@@ -526,9 +662,11 @@ class WishpyDissectorBase:
 
         This is particularly convenient while performing live capture on
         an interface or dissecting a huge file.
+
         """
         raise NotImplemented("Derived Classes need to implement this.")
 
+
 class WishpyDissectorFile(WishpyDissectorBase):
     """Dissector class for PCAP Files.
     """
@@ -542,6 +680,7 @@ class WishpyDissectorFile(WishpyDissectorBase):
         Actual function that performs the Dissection. Right now since we are
         only supporting dissecting packets from Wiretap supported files,
         only dissects packets from a pcap(ish) file.
+
         """
 
         if not _EPAN_LIB_INITIALIZED:
@@ -555,23 +694,31 @@ class WishpyDissectorFile(WishpyDissectorBase):
         # to the Exception handler
 
         # FIXME: Do this as a context manager
-        wth, wth_filetype = wtap_open_file_offline(self.__filename)
-        if wth is None:
-            raise WishpyErrorWthOpen()
-
         try:
+            wth, wth_filetype = wtap_open_file_offline(self.__filename)
+            if wth is None:
+                raise WishpyErrorWthOpen("Error Opening wiretap file: %s" % self.__filename)
+
             yield from epan_perform_dissection(self, wth, wth_filetype,
                     self.packet_to_json, count, skip)
+
+        except WishpyErrorWthOpen as e:
+            _logger.exception("WishpyDissectorFile.run:WishpyErrorWithOpen")
+            raise
+
         except Exception as e:
             _logger.exception("WishpyDissectorFile.run")
-            pass
+
         finally:
             # If we don't close `wtap` here, outer `cleanup_process` croaks
-            wtap_close(wth)
+            if wth is not None:
+                wtap_close(wth)
+
             self.cleanup_epan_dissector()
 
         return
 
+
 class WishpyDissectorQueue(WishpyDissectorBase):
     """Dissector class for packets received from a Queue(ish) object.
     """
@@ -582,8 +729,27 @@ class WishpyDissectorQueue(WishpyDissectorBase):
         This should typically call `fetch` and the perform dissection. All
         the queue based `dissectors` will dissect one packet at a time, so
         it's better that this function is in the base class.
+
         """
         hdr, data = self.fetch()
+
+        # FIXME: This might slowdown things but for now fine.
+        if isinstance(hdr, PCAPHeader):
+            newhdr = pcap_ffi.new('struct pcap_pkthdr *')
+            newhdr[0].ts.tv_sec = hdr.ts_sec
+            newhdr[0].ts.tv_usec = hdr.ts_usec
+            newhdr[0].caplen = hdr.caplen
+            newhdr[0].len = hdr.len
+
+            hdr = newhdr
+
+            if isinstance(data, bytes):
+                alloc_str = 'char [%d]' % hdr.caplen
+                newdata = epan_ffi.new(alloc_str)
+                epan_ffi.memmove(newdata, data, hdr.caplen)
+
+                data = newdata
+
         d = epan_perform_one_packet_dissection(self, self._packets_fetched,
                 hdr, data, self.packet_to_json)
 
@@ -594,11 +760,15 @@ class WishpyDissectorQueue(WishpyDissectorBase):
 
         Implementation of this function should return the object of the type
         `Hdr` and `PacketData`
+
         """
         raise NotImplemented("Derived Classes Need to implement this.")
 
 
+
 class WishpyDissectorQueuePython(WishpyDissectorQueue):
+    """Dissector class for Python Standard Library Queue.
+    """
 
     def __init__(self, queue):
 
@@ -628,6 +798,7 @@ class WishpyDissectorQueuePython(WishpyDissectorQueue):
         """yield's the packet, up to maximum of `count` packets.
 
         if count is <= 0, infinite iterator.
+
         """
 
         self.__running = True
@@ -690,6 +861,3 @@ def cleanup_process():
     global _EPAN_LIB_INITIALIZED
     _EPAN_LIB_INITIALIZED = False
 
-
-__all__ = ['WishpyDissectorFile', 'WishpyDissectorQueue',
-        'WishpyDissectorQueuePython']
