@@ -43,12 +43,14 @@ from .tvbuff_h import epan_tvbuff_h_types_cdef
 from .tvbuff_h import epan_tvbuff_h_funcs_cdef
 from .guid_utils_h import epan_guid_utils_h_types_cdef
 from .wmem_h import epan_wmem_h_types_cdef
+from .wmem_h import epan_wmem_h_funcs_cdef
 from .packet_h import epan_packet_h_funcs_cdef, epan_packet_h_types_cdef
 from .address_h import epan_address_h_types_cdef
 from .packet_info_h import epan_packet_info_h_cdef
 from .epan_dissect_h import epan_epan_dissect_h_types_cdef
 from .proto_h import epan_proto_h_types_cdef
 from .ftypes_h import epan_ftypes_h_types_cdef
+from .ftypes_h import epan_ftypes_h_funcs_cdef
 
 
 epan_ffi = FFI()
@@ -83,11 +85,13 @@ epan_ffi.cdef(epan_prefs_h_cdef)
 #epan_ffi.cdef(wsutil_ws_mempbrk_h_types_cdef)
 epan_ffi.cdef(epan_guid_utils_h_types_cdef)
 epan_ffi.cdef(epan_wmem_h_types_cdef)
+epan_ffi.cdef(epan_wmem_h_funcs_cdef)
 epan_ffi.cdef(epan_tvbuff_h_types_cdef)
 epan_ffi.cdef(epan_tvbuff_h_funcs_cdef)
 epan_ffi.cdef(epan_address_h_types_cdef)
 epan_ffi.cdef(epan_packet_info_h_cdef)
 epan_ffi.cdef(epan_ftypes_h_types_cdef)
+epan_ffi.cdef(epan_ftypes_h_funcs_cdef)
 epan_ffi.cdef(epan_proto_h_types_cdef)
 epan_ffi.cdef(epan_epan_dissect_h_types_cdef)
 epan_ffi.cdef(epan_h_cdef)
